==> applet-spring-3.1.2-sources.jar: cn/sinozg/applet/common/core/base/ErrorInfo.java <==
/*
 * Copyright (C) 2020-2024, Xie YuBin
 * The GNU Free Documentation License covers this file. The original version
 * of this license can be found at http://www.gnu.org/licenses/gfdl.html.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Free Documentation License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Free Documentation License for more details.
 *
 * You should have received a copy of the GNU Free Documentation License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

package cn.sinozg.applet.common.core.base;

import io.swagger.v3.oas.annotations.media.Schema;


/**
 * json错误返回格式
 * @Author: xyb
 * @Description:
 * @Date: 2022-11-14 下午 09:35
 **/
public class ErrorInfo {
	/** 状态码 */
	@Schema(description = "状态码")
	private String code;
	/** 错误消息 */
	@Schema(description = "错误消息")
	private String message;
	/** 请求地址 */
	@Schema(description = "url")
	private String url;

	/**
	 * 获取 状态码
	 *
	 * @return code 状态码
	 */
	public String getCode() {
		return this.code;
	}

	/**
	 * 设置 状态码
	 *
	 * @param code 状态码
	 */
	public void setCode(String code) {
		this.code = code;
	}

	/**
	 * 获取 错误消息
	 *
	 * @return message 错误消息
	 */
	public String getMessage() {
		return this.message;
	}

	/**
	 * 设置 错误消息
	 *
	 * @param message 错误消息
	 */
	public void setMessage(String message) {
		this.message = message;
	}

	/**
	 * 获取 请求地址
	 *
	 * @return url 请求地址
	 */
	public String getUrl() {
		return this.url;
	}

	/**
	 * 设置 请求地址
	 *
	 * @param url 请求地址
	 */
	public void setUrl(String url) {
		this.url = url;
	}
}

==> applet-spring-3.1.4-sources.jar: cn/sinozg/applet/common/core/base/ErrorInfo.java <==
/*
 * Copyright (C) 2020-2024, Xie YuBin
 * The GNU Free Documentation License covers this file. The original version
 * of this license can be found at http://www.gnu.org/licenses/gfdl.html.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Free Documentation License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Free Documentation License for more details.
 *
 * You should have received a copy of the GNU Free Documentation License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

package cn.sinozg.applet.common.core.base;

import io.swagger.v3.oas.annotations.media.Schema;


/**
 * json错误返回格式
 * @Author: xyb
 * @Description:
 * @Date: 2022-11-14 下午 09:35
 **/
public class ErrorInfo {
	/** 状态码 */
	@Schema(description = "状态码")
	private String code;
	/** 错误消息 */
	@Schema(description = "错误消息")
	private String message;
	/** 请求地址 */
	@Schema(description = "请求地址url")
	private String url;

	/**
	 * 获取 状态码
	 *
	 * @return code 状态码
	 */
	public String getCode() {
		return this.code;
	}

	/**
	 * 设置 状态码
	 *
	 * @param code 状态码
	 */
	public void setCode(String code) {
		this.code = code;
	}

	/**
	 * 获取 错误消息
	 *
	 * @return message 错误消息
	 */
	public String getMessage() {
		return this.message;
	}

	/**
	 * 设置 错误消息
	 *
	 * @param message 错误消息
	 */
	public void setMessage(String message) {
		this.message = message;
	}

	/**
	 * 获取 请求地址
	 *
	 * @return url 请求地址
	 */
	public String getUrl() {
		return this.url;
	}

	/**
	 * 设置 请求地址
	 *
	 * @param url 请求地址
	 */
	public void setUrl(String url) {
		this.url = url;
	}
}
